@@ -12,6 +12,9 @@ columns_dic = {'RungeKuttaEvolve:evolver:Totalenergy': 'E',
                'UniformExchange::StageMaxSpinAng': 'stage_max_spin_angle',
                'UniformExchange::RunMaxSpinAng': 'run_max_spin_angle',
                'DMExchange6Ngbr::Energy': 'E_DMI',
+               'DMI_Cnv::Energy': 'E_DMI_Cnv',
+               'DMI_T::Energy': 'E_DMI_T',
+               'DMI_D2d::Energy': 'E_DMI_D2d',
                'Demag::Energy': 'E_Demag',
                'FixedZeeman::Energy': 'E_Zeeman',
                'UZeeman::Energy': 'E_UZeeman',
@@ -19,7 +22,6 @@ columns_dic = {'RungeKuttaEvolve:evolver:Totalenergy': 'E',
                'UZeeman::Bx': 'Bx',
                'UZeeman::By': 'By',
                'UZeeman::Bz': 'Bz',
-               'BulkDMI::Energy': 'E_BulkDMI',
                'CubicAnisotropy::Energy': 'E_CubicAnisotropy',
                'TimeDriver::Iteration': 'iteration',
                'TimeDriver::Stageiteration': 'stage_iteration',
